""" This application converts PDF file to text. """

class Converter:
    """ This is a simple converter class. """

    def convert(path):
        """
        Convert a PDF file to text.

        Parameter:
        path (str): The path to a PDF file.

        Returns:
        str: The content of a PDF file as text.
        """